@@ -20,6 +20,9 @@ from sqlalchemy.testing.suite import (
 from sqlalchemy.testing.suite import (
     FetchLimitOffsetTest as _FetchLimitOffsetTest,
 )
+from sqlalchemy.testing.suite import (
+    HasTableTest as _HasTableTest,
+)
 from sqlalchemy.testing.suite import InsertBehaviorTest as _InsertBehaviorTest
 from sqlalchemy.testing.suite import IntegerTest as _IntegerTest
 from sqlalchemy.testing.suite import JoinTest as _JoinTest
@@ -77,6 +80,12 @@ class DifficultParametersTest(_DifficultParametersTest):
         # "COUNT field incorrect"
         return
 
+    @testing.skip("access")
+    def test_round_trip_same_named_column(self):
+        # bypass this test because CREATE TABLE statements fail for
+        # "[BracketsAndCase]", "dot_s", and "q?marks" cases
+        return
+
 
 class ExistsTest(_ExistsTest):
     @testing.skip("access")
@@ -152,6 +161,12 @@ class FetchLimitOffsetTest(_FetchLimitOffsetTest):
         return
 
 
+class HasTableTest(_HasTableTest):
+    @testing.skip("access")
+    def test_has_table(self):
+        return
+
+
 class InsertBehaviorTest(_InsertBehaviorTest):
     @testing.skip("access")
     def test_empty_insert(self):
